package it.mokabyte.pattern.ejb.session.stateful;

import java.rmi.*;
import javax.ejb.*;

import it.mokabyte.pattern.exception.BusinessException;

import it.mokabyte.pattern.valueobject.ProductOM;
import it.mokabyte.pattern.valueobject.AccountOM;

// import gm.demo.model.ListPagerProductModel;

/**
 * <p>Title: Facade</p>
 * <p>Description: the remote interface of the Facade</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: </p>
 * @author Rossini S. - L. Dozio
 * @version 1.0 :
 */
public interface Facade extends EJBObject {

  /**
    * Add item to the basket
    * @return price of the item added to the basket
    * @exception RemoteException Thrown to the client to indicate a System Exception on the server
    */
  public void addItem(ProductOM p) throws BusinessException,RemoteException;

  /**
    * Remove item to the basket
    * @return price of the item removed from the basket
    * @exception RemoteException Thrown to the client to indicate a System Exception on the server
    */
  public void removeItem(ProductOM p) throws BusinessException,RemoteException;

  /**
   * Return the basket size
   * @return basket size
   * @throws RemoteException
   */
  public int getBasketSize() throws RemoteException;

  /**
    * @return The current amount of the buy of the basket till now filled
    * @exception RemoteException Thrown to the client to indicate a System Exception on the server
    */
  public double getAmount() throws BusinessException,RemoteException;

  /**
    * @return The current balance in the account
    * @exception RemoteException Thrown to the client to indicate a System Exception on the server
    */
  public double getBalance() throws RemoteException;

  /**
    * @return The customer name
    * @exception RemoteException Thrown to the client to indicate a System Exception on the server
    */
  public String getName() throws RemoteException;

  /**
    * @return The customer Email
    * @exception RemoteException Thrown to the client to indicate a System Exception on the server
    */
  public String getEmail() throws RemoteException;

  /**
   * getAccount
   * @return the Object Value populated by Entity's values
   * @throws BusinessException
   * @throws RemoteException
   */
  public AccountOM getAccount() throws BusinessException,RemoteException;

  /**
    * Deposits <code>amount</code> funds in to the account.
    * @param amount The amount of money to deposit
    * @exception BankException Thrown if <code>amount</code> is negative.
    * @exception RemoteException Thrown to the client to indicate a System Exception on the server
    */
  public void deposit(double amount) throws BusinessException,RemoteException;

  /**
    * Withdraws <code>amount</code> funds from the account.
    * @param amount The amount of money to withdraw
    * @exception BankException Thrown if withdrawing <code>amount</code>
    *   would result in a negative balance, or <code>amount</code> is
    *   negetive.
    * @exception RemoteException Thrown to the client to indicate a System Exception on the server
    */
   public void withdraw(double amount) throws BusinessException, RemoteException;

}