package it.mokabyte.pattern.client;

import javax.naming.*;
import javax.rmi.PortableRemoteObject;
import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import java.rmi.RemoteException;

import it.mokabyte.pattern.ejb.session.stateful.FacadeHome;
import it.mokabyte.pattern.ejb.session.stateful.Facade;

import it.mokabyte.pattern.valueobject.ProductOM;
import it.mokabyte.pattern.valueobject.AccountOM;

import it.mokabyte.pattern.util.JndiNames;

/**
 * <p>Title:AccountTestClient </p>
 * <p>Description: simple client that <b>use</b> Facade pattern </p> and <b> Object Value </b>
 * invoke facade.getAccount() to get the Account ObectValue</p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: </p>
 * @author Rossini S. - Dozio L.
 * @version 1.0
 */
public class FacadeObjectValueTestClient {

    /** main */
    public static void main(String[] args) {
        System.out.println("starting FacadeTestClient ...");
        if(args.length == 1) {
          new FacadeObjectValueTestClient().test(args[0]);
        }
        else {
          System.out.println("usage : FacadeObjectValueTestClient <USER_ID>");
        }
    }

    /** Test the Entity EJB Account */
    public void test(String userid) {
      try {
          Context ctx =  new InitialContext();
          System.out.println("Lookup for ["+JndiNames.FACADE+"]...");
          //look up jndi name
          Object obj = ctx.lookup(JndiNames.FACADE);
          System.out.println("Lookup done : obj class["+obj.getClass().getName()+"] ...");
          System.out.println("Lookup done : obj ["+obj+"] ...");
          //cast to Home interface
          FacadeHome facadeHome = (FacadeHome)PortableRemoteObject.narrow(obj, FacadeHome.class);
          System.out.println("Narrow done ...facadeHome["+facadeHome+"]...");
          // start the test
          // find the account
          Facade facade = facadeHome.create(userid);

          // *********************************************
          // read data by Object Value (one remote call !)
          // *********************************************
          AccountOM objectValue = facade.getAccount();
          System.out.println("User account name    : " + objectValue.getName());
          System.out.println("User account email   : " + objectValue.getAddress());
          System.out.println("User account balance : " + objectValue.getBalance());

        } catch(ClassCastException cce) {
            System.out.println(" # ClassCastExceptionException : " + cce.getMessage());
            cce.printStackTrace();
        } catch(NamingException ne) {
            System.out.println(" # NamingException : " + ne.getMessage());
            ne.printStackTrace();
        } catch(CreateException ce) {
            System.out.println(" # CreateException : " + ce.getMessage());
            ce.printStackTrace();
        } catch(RemoteException re) {
            System.out.println(" # RemoteException : " + re.getMessage());
            re.printStackTrace();
        }
        catch(Exception e) {
            System.out.println(" # Exception  : " + e.getMessage());
            e.printStackTrace();
        }
    }
}